@@ -6,7 +6,7 @@ use Duadua::Util qw//;
 sub try {
     my ($class, $d) = @_;
 
-    if ( $d->contain(' FlipboardRSS/') ) {
+    if ( $d->_contain(' FlipboardRSS/') ) {
         my $h = {
             name   => 'Flipboard',
             is_bot => 1,
